@@ -36,7 +36,7 @@ window2py(void* value)
 static int setup_carbon(PyObject* m __attribute__((__unused__)))
 {
 #if PY_MAJOR_VERSION == 2 && defined(USE_TOOLBOX_OBJECT_GLUE)
-	if (PyObjCPointerWrapper_Register(@encode(WindowRef),
+	if (PyObjCPointerWrapper_Register("WindowRef", @encode(WindowRef),
 	                &window2py, &py2window) < 0)
 		return -1;
 #endif
