@@ -2,6 +2,12 @@ from CoreFoundation import *
 
 from PyObjCTools.TestSupport import *
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestCFBinaryHeap (TestCase):
     def testTypes(self):
         self.assertIsCFType(CFBinaryHeapRef)
