@@ -3,10 +3,22 @@ from CoreFoundation import *
 from Foundation import NSCFData
 import sys
 
+try:
+    long
+except NameError:
+    long = int
+
+
 
 class TestData (TestCase):
     def testTypes(self):
+        try:
+            NSCFData = objc.lookUpClass('__NSCFData')
+        except objc.error:
+            NSCFData = objc.lookUpClass('NSCFData')
+
         self.assertIs(CFDataRef, NSCFData)
+
     def testTypeID(self):
         v = CFDataGetTypeID()
         self.assertTrue(v, (int, long))
@@ -92,6 +104,5 @@ class TestData (TestCase):
         self.assertIsInstance(v, CFRange)
         self.assertEqual(v, (6, 3))
 
-
 if __name__ == "__main__":
     main()
