@@ -3,6 +3,17 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 import sys
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestURLAccess (TestCase):
     def testConstants(self):
@@ -23,6 +34,7 @@ class TestURLAccess (TestCase):
         self.assertIsInstance( kCFURLFileOwnerID, unicode)
         self.assertIsInstance( kCFURLHTTPStatusCode, unicode)
         self.assertIsInstance( kCFURLHTTPStatusLine, unicode)
+
     def testFunctions(self):
         url = CFURLCreateWithFileSystemPath(None, __file__, kCFURLPOSIXPathStyle, False)
 
@@ -57,7 +69,8 @@ class TestURLAccess (TestCase):
         self.assertTrue(ok)
         self.assertIsInstance(errorCode, (int, long))
         self.assertTrue(os.path.exists(__file__ + "TEST"))
-        data = open(__file__ + "TEST", 'r').read()
+        with open(__file__ + "TEST", 'r') as fp:
+            data = fp.read()
         self.assertEqual(data , 'foobar')
         self.assertResultIsBOOL(CFURLDestroyResource)
         self.assertArgIsOut(CFURLDestroyResource, 1)
@@ -66,8 +79,5 @@ class TestURLAccess (TestCase):
         self.assertIsInstance(errorCode, (int, long))
         self.assertFalse(os.path.exists(__file__ + "TEST"))
 
-
-            
-                
 if __name__ == "__main__":
     main()
