@@ -1,6 +1,17 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestXMLParser (TestCase):
     # Note: This doesn't actually test the API
@@ -10,6 +21,7 @@ class TestXMLParser (TestCase):
 
     def testTypeID(self):
         self.assertIsInstance(CFXMLParserGetTypeID(), (int, long))
+
     def testConstants(self):
         self.assertEqual(kCFXMLParserValidateDocument , (1 << 0) )
         self.assertEqual(kCFXMLParserSkipMetaData , (1 << 1) )
@@ -41,5 +53,10 @@ class TestXMLParser (TestCase):
         self.assertIsInstance(kCFXMLTreeErrorLineNumber, unicode)
         self.assertIsInstance(kCFXMLTreeErrorLocation, unicode)
         self.assertIsInstance(kCFXMLTreeErrorStatusCode, unicode)
+
+    @expectedFailure
+    def testMissingWrappers(self):
+        self.fail("Missing manual wrappers for CFXMLParser (low prio)")
+
 if __name__ == "__main__":
     main()
