@@ -18,6 +18,7 @@ class FoundationErrorsTest (TestCase):
         self.assertEqual(NSFileWriteInvalidFileNameError, 514)
         self.assertEqual(NSFileWriteInapplicableStringEncodingError, 517)
         self.assertEqual(NSFileWriteUnsupportedSchemeError, 518)
+        self.assertEqual(NSFileWriteOutOfSpaceError, 640)
         self.assertEqual(NSKeyValueValidationError, 1024)
         self.assertEqual(NSUserCancelledError, 3072)
         self.assertEqual(NSExecutableNotLoadableError, 3584)
@@ -33,6 +34,7 @@ class FoundationErrorsTest (TestCase):
         self.assertEqual(NSExecutableErrorMaximum, 3839)
         self.assertEqual(NSFormattingErrorMinimum, 2048)
         self.assertEqual(NSFormattingErrorMaximum, 2559)
+        self.assertEqual(NSFormattingError, 2048)
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -45,6 +47,18 @@ class FoundationErrorsTest (TestCase):
         self.assertEqual(NSPropertyListErrorMinimum, 3840)
         self.assertEqual(NSPropertyListErrorMaximum, 4095)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(NSFileWriteFileExistsError, 516)
+
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(NSFeatureUnsupportedError, 3328)
+        self.assertEqual(NSXPCConnectionInterrupted, 4097)
+        self.assertEqual(NSXPCConnectionInvalid, 4099)
+        self.assertEqual(NSXPCConnectionReplyInvalid, 4101)
+        self.assertEqual(NSXPCConnectionErrorMinimum, 4096)
+        self.assertEqual(NSXPCConnectionErrorMaximum, 4224)
 
 if __name__ == "__main__":
     main()
