@@ -2,17 +2,22 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSFontDescriptor (TestCase):
     def testConstants(self):
-        self.assertEqual(NSFontUnknownClass, cast_int(0 << 28))
-        self.assertEqual(NSFontOldStyleSerifsClass, cast_int(1 << 28))
-        self.assertEqual(NSFontModernSerifsClass, cast_int(3 << 28))
-        self.assertEqual(NSFontSlabSerifsClass, cast_int(5 << 28))
-        self.assertEqual(NSFontSansSerifClass, cast_int(8 << 28))
-        self.assertEqual(NSFontScriptsClass, cast_int(10 << 28))
-        self.assertEqual(NSFontSymbolicClass, cast_int(12 << 28))
+        self.assertEqual(NSFontUnknownClass, (0 << 28))
+        self.assertEqual(NSFontOldStyleSerifsClass, (1 << 28))
+        self.assertEqual(NSFontModernSerifsClass, (3 << 28))
+        self.assertEqual(NSFontSlabSerifsClass, (5 << 28))
+        self.assertEqual(NSFontSansSerifClass, (8 << 28))
+        self.assertEqual(NSFontScriptsClass, (10 << 28))
+        self.assertEqual(NSFontSymbolicClass, (12 << 28))
 
-        self.assertEqual(NSFontFamilyClassMask, cast_int(0xF0000000))
+        self.assertEqual(NSFontFamilyClassMask, (0xF0000000))
 
         self.assertEqual(NSFontItalicTrait, (1 << 0))
         self.assertEqual(NSFontBoldTrait, (1 << 1))
