@@ -2,10 +2,17 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSKeyValueBindingHelper (NSObject):
     def commitEditingWithDelegate_didCommitSelector_contextInfo_(self, d, s, i):
         return None
 
+    def commitEditingAndReturnError_(self, v): return 1
+
     def commitEditing(self): return 1
 
 
@@ -129,10 +136,15 @@ class TestNSKeyValueBinding (TestCase):
         self.assertIsInstance(NSTransparentBinding, unicode)
         self.assertIsInstance(NSContentPlacementTagBindingOption, unicode)
 
+    @min_os_level("10.7")
+    def testConstants10_7(self):
+        self.assertIsInstance(NSPositioningRectBinding, unicode)
+
     def testFunctions(self):
         o = NSObject.alloc().init()
         self.assertIs(NSIsControllerMarker(o), False)
         self.assertIs(NSIsControllerMarker(NSMultipleValuesMarker), True)
+
     def testMethods(self):
         o = TestNSKeyValueBindingHelper.alloc().init()
         m = o.commitEditingWithDelegate_didCommitSelector_contextInfo_.__metadata__()
@@ -140,6 +152,12 @@ class TestNSKeyValueBinding (TestCase):
 
         self.assertResultIsBOOL(TestNSKeyValueBindingHelper.commitEditing)
 
+    @min_os_level('10.7')
+    @expectedFailure
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(TestNSKeyValueBindingHelper.commitEditingAndReturnError_)
+        self.assertArgIsOut(TestNSKeyValueBindingHelper.commitEditingAndReturnError_, 0)
+
 
 
 if __name__ == "__main__":
