@@ -2,7 +2,12 @@
 from PyObjCTools.TestSupport import *
 import objc
 
-from Foundation import NSLocalizedString
+from Foundation import NSLocalizedString, NSAutoreleasePool
+
+try:
+    unicode
+except NameError:
+    unicode = str
 
 class TestNSLocalizedString(TestCase):
     def testBasic(self):
@@ -11,11 +16,12 @@ class TestNSLocalizedString(TestCase):
         if objc.platform != 'MACOSX':
             return
 
-        s = NSLocalizedString(u"hello world", u"")
-        objc.recycleAutoreleasePool()
-        self.assertEqual (s, u"hello world")
+        pool = NSAutoreleasePool.alloc().init()
+        s = NSLocalizedString(b"hello world".decode('ascii'), b"".decode('ascii'))
+        del pool
+        self.assertEqual (s, b"hello world".decode('ascii'))
         # XXX : Since we get the same object back, it's still unicode
-        #self.assertEqual (s.nsstring().description(), u"hello world")
+        #self.assertEqual (s.nsstring().description(), b"hello world".decode('ascii'))
 
 if __name__ == '__main__':
     main( )
