@@ -2,12 +2,21 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestNSObjectHelper (NSObject):
     def copyWithZone_(self, zn): return None
     def mutableCopyWithZone_(self, zn): return None
     def isContentDiscarded(self): return 1
     def beginContentAccess(self): return 1
 
+    def retainWeakReference(self): return 0
+    def allowsWeakReference(self): return 0
+
 
 class TestNSObjectFunctions (TestCase):
     def testAllocation(self):
@@ -45,9 +54,6 @@ class TestNSObjectFunctions (TestCase):
 
 
 
-
-
-
 class TestNSObjectInteraction(TestCase):
     def testCallingInstanceMethodWithClassSelf(self):
         self.assertRaises(TypeError, NSObject.description, NSObject)
@@ -96,6 +102,7 @@ class TestNSObjectInteraction(TestCase):
         self.assertResultIsBOOL(NSObject.resolveClassMethod_)
         self.assertResultIsBOOL(NSObject.resolveInstanceMethod_)
 
+
         o = NSObject.alloc().init()
         self.assertResultIsBOOL(o.isEqual_)
         self.assertResultIsBOOL(o.isProxy)
@@ -114,6 +121,10 @@ class TestNSObjectInteraction(TestCase):
         self.assertResultIsBOOL(TestNSObjectHelper.beginContentAccess)
         self.assertResultIsBOOL(TestNSObjectHelper.isContentDiscarded)
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(TestNSObjectHelper.allowsWeakReference)
+        self.assertResultIsBOOL(TestNSObjectHelper.retainWeakReference)
 
 if __name__ == '__main__':
     main( )
