@@ -1,6 +1,11 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSOperation (TestCase):
     def testConstants(self):
         self.assertEqual(NSOperationQueuePriorityVeryLow, -8)
@@ -23,6 +28,7 @@ class TestNSOperation (TestCase):
         self.assertResultIsBOOL(NSOperationQueue.isSuspended)
         self.assertArgIsBOOL(NSOperationQueue.setSuspended_, 0)
 
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertResultIsBlock(NSOperation.completionBlock, b'v')
