@@ -1,6 +1,16 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    import CFNetwork
+except ImportError:
+    CFNetwork = None
+
 class TestNSURLError (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSURLErrorDomain, unicode)
@@ -52,10 +62,19 @@ class TestNSURLError (TestCase):
 
     @min_os_level('10.6')
     def testConstants10_6(self):
+        self.assertIsInstance(NSURLErrorFailingURLPeerTrustErrorKey, unicode)
         self.assertIsInstance(NSURLErrorFailingURLErrorKey, unicode)
         self.assertIsInstance(NSURLErrorFailingURLStringErrorKey, unicode)
 
         self.assertEqual(NSURLErrorClientCertificateRequired, -1206)
 
+    @min_os_level('10.7')
+    @onlyIf(CFNetwork is not None)
+    def testConstants10_7(self):
+        self.assertEqual(NSURLErrorInternationalRoamingOff, CFNetwork.kCFURLErrorInternationalRoamingOff)
+        self.assertEqual(NSURLErrorCallIsActive, CFNetwork.kCFURLErrorCallIsActive)
+        self.assertEqual(NSURLErrorDataNotAllowed, CFNetwork.kCFURLErrorDataNotAllowed)
+        self.assertEqual(NSURLErrorRequestBodyStreamExhausted, CFNetwork.kCFURLErrorRequestBodyStreamExhausted)
+
 if __name__ == "__main__":
     main()
