@@ -1,6 +1,11 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestValueTrans (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSNegateBooleanTransformerName, unicode)
@@ -8,6 +13,7 @@ class TestValueTrans (TestCase):
         self.assertIsInstance(NSIsNotNilTransformerName, unicode)
         self.assertIsInstance(NSUnarchiveFromDataTransformerName, unicode)
         self.assertIsInstance(NSKeyedUnarchiveFromDataTransformerName, unicode)
+
     def testMethods(self):
         self.assertResultIsBOOL(NSValueTransformer.allowsReverseTransformation)
 
